# ---
# jupyter:
#   jupytext:
#     cell_markers: '{{{,}}}'
#   kernelspec:
#     display_name: Python 3
#     language: python
#     name: python3
# ---

# {{{
# %%time

print('asdf')
# }}}

# Thanks for jupytext!


